@@ -219,21 +219,33 @@ class CIFMixin:
         # Add the atoms
         # TEMPORARILY lower the symmetry to P1
         delta = 1.0e-04
+
+        # Where is the symmetry info?
+        if "_space_group_symop_operation_xyz" in data_block:
+            symdata = "_space_group_symop_operation_xyz"
+        elif "_symmetry_equiv_pos_as_xyz" in data_block:
+            symdata = "_symmetry_equiv_pos_as_xyz"
+        else:
+            raise RuntimeError(
+                "CIF file does not contain required symmetry information. Neither "
+                "'_symmetry_equiv_pos_as_xyz' or '_space_group_symop_operation_xyz' "
+                "is present."
+            )
+        xs = []
+        ys = []
+        zs = []
+        symbols = []
         for x, y, z, symbol in zip(
             data_block["_atom_site_fract_x"],
             data_block["_atom_site_fract_y"],
             data_block["_atom_site_fract_z"],
             data_block["_atom_site_type_symbol"],
         ):  # yapf: disable
-            xs = []
-            ys = []
-            zs = []
-            symbols = []
             # These variables *are* used in the eval below.
             x = float(x)
             y = float(y)
             z = float(z)
-            for symop in data_block["_space_group_symop_operation_xyz"]:
+            for symop in data_block[symdata]:
                 x_eq, y_eq, z_eq = symop.split(",")
                 x_new = eval(x_eq)
                 y_new = eval(y_eq)
@@ -263,7 +275,7 @@ class CIFMixin:
                     ys.append(y_new)
                     zs.append(z_new)
                     symbols.append(symbol)
-            self.atoms.append(x=xs, y=ys, z=zs, symbol=symbols)
+        self.atoms.append(x=xs, y=ys, z=zs, symbol=symbols)
 
     def to_mmcif_text(self):
         """Create the text of a mmCIF file from this configuration.
